@@ -1,13 +1,16 @@
 #! /usr/bin/python
 # -*- coding: utf-8 -*-
 
-# Other Libraries
+# Owned Libraries
 from z2n import prompt
 
 
-def cli() -> None:
+def cli() -> int:
     """Entry point to the Z2n Software."""
-    prompt.z2n()
+    try:
+        prompt.z2n()
+    except SystemExit:
+        return 0
 
 
 if __name__ == "__main__":
